aboutsummaryrefslogtreecommitdiff
path: root/src/or/rendservice.c
diff options
context:
space:
mode:
authorteor <teor2345@gmail.com>2016-09-13 17:28:03 +1000
committerNick Mathewson <nickm@torproject.org>2016-09-13 10:13:57 -0400
commitf311c9ffa2d9cdb64b92e4ceab5b3c582b976228 (patch)
treec45eee9cc5caa6834d156ca727b4f1534f686b3a /src/or/rendservice.c
parent365ca3ca0f5d9d391a2156436d1a7c620906e23a (diff)
downloadtor-f311c9ffa2d9cdb64b92e4ceab5b3c582b976228.tar.gz
tor-f311c9ffa2d9cdb64b92e4ceab5b3c582b976228.zip
Replace OnionService* with HiddenService* in option names
And make consequential line-length adjustments.
Diffstat (limited to 'src/or/rendservice.c')
-rw-r--r--src/or/rendservice.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/or/rendservice.c b/src/or/rendservice.c
index 9400b591ee..cce63f29fa 100644
--- a/src/or/rendservice.c
+++ b/src/or/rendservice.c
@@ -4179,26 +4179,26 @@ rend_service_set_connection_addr_port(edge_connection_t *conn,
return -2;
}
/* Are OnionServiceSingleHopMode and OnionServiceNonAnonymousMode consistent?
*/
static int
rend_service_non_anonymous_mode_consistent(const or_options_t *options)
{
/* !! is used to make these options boolean */
- return (!! options->OnionServiceSingleHopMode ==
- !! options->OnionServiceNonAnonymousMode);
+ return (!! options->HiddenServiceSingleHopMode ==
+ !! options->HiddenServiceNonAnonymousMode);
}
/* Do the options allow onion services to make direct (non-anonymous)
* connections to introduction or rendezvous points?
* Must only be called after options_validate_single_onion() has successfully
* checked onion service option consistency.
* Returns true if tor is in OnionServiceSingleHopMode. */
int
rend_service_allow_non_anonymous_connection(const or_options_t *options)
{
tor_assert(rend_service_non_anonymous_mode_consistent(options));
- return options->OnionServiceSingleHopMode ? 1 : 0;
+ return options->HiddenServiceSingleHopMode ? 1 : 0;
}
/* Do the options allow us to reveal the exact startup time of the onion
@@ -4215,7 +4215,7 @@ rend_service_reveal_startup_time(const or_options_t *options)
return rend_service_non_anonymous_mode_enabled(options);
}
/* Is non-anonymous mode enabled using the OnionServiceNonAnonymousMode
* config option?
* Must only be called after options_validate_single_onion() has successfully
* checked onion service option consistency.
@@ -4224,5 +4224,5 @@ int
rend_service_non_anonymous_mode_enabled(const or_options_t *options)
{
tor_assert(rend_service_non_anonymous_mode_consistent(options));
- return options->OnionServiceNonAnonymousMode ? 1 : 0;
+ return options->HiddenServiceNonAnonymousMode ? 1 : 0;
}
@@ -4179,26 +4179,26 @@ rend_service_set_connection_addr_port(edge_connection_t *conn,
return -2;
}
-/* Are OnionServiceSingleHopMode and OnionServiceNonAnonymousMode consistent?
+/* Are HiddenServiceSingleHopMode and HiddenServiceNonAnonymousMode consistent?
*/
static int
@@ -4179,26 +4179,26 @@ rend_service_set_connection_addr_port(edge_connection_t *conn,
* Must only be called after options_validate_single_onion() has successfully
* checked onion service option consistency.
- * Returns true if tor is in OnionServiceSingleHopMode. */
+ * Returns true if tor is in HiddenServiceSingleHopMode. */
int
rend_service_allow_non_anonymous_connection(const or_options_t *options)
@@ -4215,7 +4215,7 @@ rend_service_reveal_startup_time(const or_options_t *options)
return rend_service_non_anonymous_mode_enabled(options);
}
-/* Is non-anonymous mode enabled using the OnionServiceNonAnonymousMode
+/* Is non-anonymous mode enabled using the HiddenServiceNonAnonymousMode
* config option?
* Must only be called after options_validate_single_onion() has successfully